summaryrefslogtreecommitdiff
path: root/vms/genconfig.pl
diff options
context:
space:
mode:
Diffstat (limited to 'vms/genconfig.pl')
-rw-r--r--vms/genconfig.pl8
1 files changed, 4 insertions, 4 deletions
diff --git a/vms/genconfig.pl b/vms/genconfig.pl
index ef1d5ad4a5..2794a172a1 100644
--- a/vms/genconfig.pl
+++ b/vms/genconfig.pl
@@ -157,8 +157,8 @@ foreach (@ARGV) {
$optimize = $qual;
$ccflags =~ s/$qual//;
}
- $usethreads = ($ccflags =~ m!/DEF[^/]+USE_THREADS!i and
- $ccflags !~ m!/UND[^/]+USE_THREADS!i);
+ $usethreads = ($ccflags =~ m!/DEF[^/]+USE_5005THREADS!i and
+ $ccflags !~ m!/UND[^/]+USE_5005THREADS!i);
print OUT "usethreads='",($usethreads ? 'define' : 'undef'),"'\n";;
$optimize = "$debug$optimize";
print OUT "ccflags='$ccflags'\n";
@@ -367,8 +367,8 @@ close IN;
# as the manifest for the obsolete variable $d_eunice.
print OUT "d_eunice='undef'\n"; delete $pp_vars{VMS};
-# XXX temporary -- USE_THREADS is currently on CC command line
-delete $pp_vars{'USE_THREADS'};
+# XXX temporary -- USE_5005THREADS is currently on CC command line
+delete $pp_vars{'USE_5005THREADS'};
foreach (sort keys %pp_vars) {
warn "Didn't see $_ in $infile\n";